# XML Encoder

## Examples

### Encoding a file

```Python
import xml_encoder

path_in  = '/foo/bar.xml'
path_out = '/foo/bar.exml'

xml_encoder.encode(path_in, path_out)
```

### Decoding a file
```Python
import xml_encoder

path_in  = '/foo/bar.exml'
path_out = '/foo/bar.xml'

xml_encoder.decode(path_in, path_out)
```

## Contact

If you have any questions or concerns, please reach out to me (John Carter) at jfcarter2358@gmail.com